@@ -12,13 +12,13 @@ import django
 from sphinxawesome_theme.postprocess import Icons
 
 sys.path.insert(0, os.path.abspath("../.."))
-os.environ["DJANGO_SETTINGS_MODULE"] = "terminusgps.settings"
+os.environ["DJANGO_SETTINGS_MODULE"] = "terminusgps.django.settings"
 django.setup()
 
 project = "python-terminusgps"
 copyright = "2025, Terminus GPS, LLC"
 author = "Terminus GPS, LLC"
-release = "30.0.0"
+release = "30.1.0"
 
 # -- General configuration ---------------------------------------------------
 # https://www.sphinx-doc.org/en/master/usage/configuration.html#general-configuration
